require 'pathname'
require 'yaml'

module BBC
  module Cosmos
    module Tools
      module Config
        class ProjectConfig

          def initialize(config_path, project, env = 'int')
            @project = project
            @env = env
            @config_path = config_path
          end

          def components
            config['components'].keys
          end

          def generate(id)
            component_config id
          end

          def generate_cosmos(id)
            generate(id).reduce([]) do |object, (key, value)|
              object.tap { |o| o << {:value => value, :key => key} }
            end
          end

          private

          def environment_exists?
            File.directory? File.join(@config_path, @env)
          end

          def config_path
            if environment_exists?
              path = File.join(@config_path, @env, "#{@project}.yaml")
              if File.exist? path
                File.open(path).read
              else
                raise("#{@project} isn't a valid project")
              end
            else
              raise("#{@env} is an invalid environment")
            end
          end

          def config
            @config ||= YAML::load(config_path)
          end

          def component_config(id)
            raise('Invalid component id') if config['components'][id].nil?
            config['components'][id]
          end
        end
      end
    end
  end
end
